GeneralSchemaApi<AGeneralSchemaEnsureInitializedValue, AGeneralSchemaDatabaseValue extends GeneralSchemaDatabase, AGeneralSchemaInvokeValue, AGeneralSchemaInvokeValueOptions> class abstract

General Library Documentation Undocument By General Corporation & Global Corporation & General Developer

Inheritance
Mixed-in types

Constructors

GeneralSchemaApi({required AGeneralSchemaDatabaseValue generalSchemaDatabase})
General Library Documentation Undocument By General Corporation & Global Corporation & General Developer

Properties

generalSchemaDatabase → AGeneralSchemaDatabaseValue
General Library Documentation Undocument By General Corporation & Global Corporation & General Developer
final
generalSchemaEnsureInitialized ↔ AGeneralSchemaEnsureInitializedValue
General Library Documentation Undocument By General Corporation & Global Corporation & General Developer
getter/setter pairinherited
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

dispose() → FutureOr<void>
GeneralLib
inherited
ensureInitialized({required AGeneralSchemaEnsureInitializedValue generalSchemaEnsureInitialized}) → FutureOr<void>
GeneralLib
override
getDetailStatusDeviceSupportAsync() → FutureOr<GeneralSchemaDeviceStatusSupportType>
GeneralLib
inherited
getDetailStatusDeviceSupportSync() → GeneralSchemaDeviceStatusSupportType
GeneralLib
inherited
getLibraryStatusTypeAsync() → FutureOr<GeneralSchemaLibraryStatusType>
GeneralLib
inherited
getLibraryStatusTypeSync() → GeneralSchemaLibraryStatusType
GeneralLib
inherited
initialized() → FutureOr<void>
GeneralLib
inherited
invoke({required AGeneralSchemaInvokeValue invokeParameters, required AGeneralSchemaInvokeValueOptions? invokeOptions}) → FutureOr<AGeneralSchemaInvokeValue>
General Library Documentation Undocument By General Corporation & Global Corporation & General Developer
inherited
invokeRaw({required AGeneralSchemaInvokeValue invokeParameters, required AGeneralSchemaInvokeValueOptions? invokeOptions}) → FutureOr<AGeneralSchemaInvokeValue>
General Library Documentation Undocument By General Corporation & Global Corporation & General Developer
inherited
isDeviceSupportAsync() → FutureOr<bool>
GeneralLib
inherited
isDeviceSupportSync() → bool
GeneralLib
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
request({required AGeneralSchemaInvokeValue invokeParameters, required AGeneralSchemaInvokeValueOptions? invokeOptions}) → FutureOr<AGeneralSchemaInvokeValue>
General Library Documentation Undocument By General Corporation & Global Corporation & General Developer
inherited
toString() → String
A string representation of this object.
inherited
valueBuilderAsync<T extends Object?>({required FutureOr<T> onValueBuilder(), required FutureOr<T> onErrorValueBuilder(dynamic error, StackTrace stackTrace)}) → FutureOr<T>
General Library Documentation Undocument By General Corporation & Global Corporation & General Developer
inherited
valueBuilderSync<T extends Object?>({required T onValueBuilder(), required T onErrorValueBuilder(dynamic error, StackTrace stackTrace)}) → T
General Library Documentation Undocument By General Corporation & Global Corporation & General Developer
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited