GeneralSchemaBaseCore<AGeneralSchemaEnsureInitializedValue> class abstract

GeneralLib

Implementers

Constructors

GeneralSchemaBaseCore()

Properties

generalSchemaEnsureInitialized ↔ AGeneralSchemaEnsureInitializedValue
General Library Documentation Undocument By General Corporation & Global Corporation & General Developer
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

dispose() → FutureOr<void>
GeneralLib
ensureInitialized({required AGeneralSchemaEnsureInitializedValue generalSchemaEnsureInitialized}) → FutureOr<void>
GeneralLib
getDetailStatusDeviceSupportAsync() → FutureOr<GeneralSchemaDeviceStatusSupportType>
GeneralLib
getDetailStatusDeviceSupportSync() → GeneralSchemaDeviceStatusSupportType
GeneralLib
getLibraryStatusTypeAsync() → FutureOr<GeneralSchemaLibraryStatusType>
GeneralLib
getLibraryStatusTypeSync() → GeneralSchemaLibraryStatusType
GeneralLib
initialized() → FutureOr<void>
GeneralLib
isDeviceSupportAsync() → FutureOr<bool>
GeneralLib
isDeviceSupportSync() → bool
GeneralLib
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
valueBuilderAsync<T extends Object?>({required FutureOr<T> onValueBuilder(), required FutureOr<T> onErrorValueBuilder(dynamic error, StackTrace stackTrace)}) → FutureOr<T>
General Library Documentation Undocument By General Corporation & Global Corporation & General Developer
valueBuilderSync<T extends Object?>({required T onValueBuilder(), required T onErrorValueBuilder(dynamic error, StackTrace stackTrace)}) → T
General Library Documentation Undocument By General Corporation & Global Corporation & General Developer

Operators

operator ==(Object other) → bool
The equality operator.
inherited